geowatch.cli.coco\_update\_geotiff\_metadata module
===================================================

.. automodule:: geowatch.cli.coco_update_geotiff_metadata
   :members:
   :undoc-members:
   :show-inheritance:
